.. _SAM:

**********
CAMELS-SAM
**********

The ``SCSAM`` folder contains the CAMELS-SAM data. CAMELS-SAM is set of collection of more than 1,000 galaxy catalogues, each of them from a different cosmological and astrophysical model spanning a periodic comoving volume of :math:`(100~h^{-1}{\rm Mpc})^3`. Each catalogue was constructed by running an N-body simulation and applying the Santa Cruz Semi-Analytic Model on top of it.

We refer the user to the `CAMELS-SAM website <https://camels-sam.readthedocs.io>`_ for further details on it, its data structure (that is different to the generic one described in :ref:`suite_folders`), and how to read and manipulate the data.
